
/*-------------------------------------------------------------*/
netwib_err netwib_debug_disp_string(netwib_conststring msg);
netwib_err netwib_debug_disp_fmt(netwib_conststring fmt,
                                 ...);

/*-------------------------------------------------------------*/
netwib_err netwib_debug_disp_dump(netwib_constdata data,
                                  netwib_uint32 datasize);
